==> core-react-0.8.0.tgz: package/es/Layout/Col/index.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';


var Col = function Col(props) {
  var children = props.children,
      className = props.className,
      col = props.col,
      right = props.right,
      other = _objectWithoutProperties(props, ["children", "className", "col", "right"]);

  var classNames = cx("".concat("waui", "-layout__col"), col && col.split(' ').map(function (v) {
    return "".concat("waui", "-layout__col_").concat(v);
  }), _defineProperty({}, "".concat("waui", "-layout__col_right"), right), className);
  return React.createElement("div", _extends({
    className: classNames
  }, other), children);
};

Col.propTypes = {
  children: PropTypes.node,
  className: PropTypes.string,

  /** Total 24 cols, such as `col="md-6 sm-24"` */
  col: PropTypes.string,

  /** Whether to align right */
  right: PropTypes.bool
};
export default Col;

==> core-react-0.8.2.tgz: package/es/Layout/Col/index.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';


var Col = function Col(props) {
  var children = props.children,
      className = props.className,
      col = props.col,
      right = props.right,
      other = _objectWithoutProperties(props, ["children", "className", "col", "right"]);

  var classNames = cx("".concat("waui", "-layout__col"), col && col.split(' ').map(function (v) {
    return "".concat("waui", "-layout__col_").concat(v);
  }), _defineProperty({}, "".concat("waui", "-layout__col_right"), right), className);
  return (/*#__PURE__*/React.createElement("div", _extends({
      className: classNames
    }, other), children)
  );
};

Col.propTypes = {
  children: PropTypes.node,
  className: PropTypes.string,

  /** Total 24 cols, such as `col="md-6 sm-24"` */
  col: PropTypes.string,

  /** Whether to align right */
  right: PropTypes.bool
};
export default Col;
